**2.0.1 - 06/14/2024**

 - Add py.typed marker

**2.0.0 - 05/17/2024**

 - Drop support for Python v3.8
 - Add type hints

**1.0.2 - 04/26/2024**

 - Allow default None argument for ConfigurationError

**1.0.1 - 04/11/2024**

 - Extract python version test matrix from python_versions.json
 - Automatically update README when supported python versions change
 - Bugfix missing ConfigurationError attribute

**1.0.0 - 04/11/2024**

 - Initial release
